[PATCH 2/4] ddraw: Send device2_Draw* through device3_Draw*

Stefan Dösinger stefan at codeweavers.com
Thu Jun 20 05:17:06 CDT 2013


---
 dlls/ddraw/device.c | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/dlls/ddraw/device.c b/dlls/ddraw/device.c
index 8e86f55..0b20413 100644
--- a/dlls/ddraw/device.c
+++ b/dlls/ddraw/device.c
@@ -2195,7 +2195,7 @@ static HRESULT WINAPI d3d_device2_Index(IDirect3DDevice2 *iface, WORD index)
  * Ends a draw begun with IDirect3DDevice3::Begin or
  * IDirect3DDevice::BeginIndexed. The vertices specified with
  * IDirect3DDevice::Vertex or IDirect3DDevice::Index are drawn using
  * the IDirect3DDevice7::DrawPrimitive method. So far only
  * non-indexed mode is supported
  *
  * Version 2 and 3
@@ -2204,7 +2204,7 @@ static HRESULT WINAPI d3d_device2_Index(IDirect3DDevice2 *iface, WORD index)
  *  Flags: Some flags, as usual. Don't know which are defined
  *
  * Returns:
  *  The return value of IDirect3DDevice7::DrawPrimitive
  *
  *****************************************************************************/
 static HRESULT WINAPI d3d_device3_End(IDirect3DDevice3 *iface, DWORD flags)
@@ -2213,7 +2213,7 @@ static HRESULT WINAPI d3d_device3_End(IDirect3DDevice3 *iface, DWORD flags)
 
     TRACE("iface %p, flags %#x.\n", iface, flags);
 
-    return IDirect3DDevice7_DrawPrimitive(&device->IDirect3DDevice7_iface, device->primitive_type,
+    return IDirect3DDevice3_DrawPrimitive(&device->IDirect3DDevice3_iface, device->primitive_type,
             device->vertex_type, device->sysmem_vertex_buffer, device->nb_vertices, device->render_flags);
 }
 
@@ -3545,7 +3545,7 @@ static HRESULT WINAPI d3d_device2_DrawPrimitive(IDirect3DDevice2 *iface,
             return DDERR_INVALIDPARAMS;  /* Should never happen */
     }
 
-    return IDirect3DDevice7_DrawPrimitive(&device->IDirect3DDevice7_iface,
+    return IDirect3DDevice3_DrawPrimitive(&device->IDirect3DDevice3_iface,
             primitive_type, fvf, vertices, vertex_count, flags);
 }
 
@@ -3728,7 +3728,7 @@ static HRESULT WINAPI d3d_device2_DrawIndexedPrimitive(IDirect3DDevice2 *iface,
             return DDERR_INVALIDPARAMS;  /* Should never happen */
     }
 
-    return IDirect3DDevice7_DrawIndexedPrimitive(&device->IDirect3DDevice7_iface,
+    return IDirect3DDevice3_DrawIndexedPrimitive(&device->IDirect3DDevice3_iface,
             primitive_type, fvf, vertices, vertex_count, indices, index_count, flags);
 }
 
@@ -2195,7 +2195,7 @@ static HRESULT WINAPI d3d_device2_Index(IDirect3DDevice2 *iface, WORD index)
  * IDirect3DDevice::BeginIndexed. The vertices specified with
  * IDirect3DDevice::Vertex or IDirect3DDevice::Index are drawn using
- * the IDirect3DDevice7::DrawPrimitive method. So far only
+ * the IDirect3DDevice3::DrawPrimitive method. So far only
  * non-indexed mode is supported
  *
@@ -2204,7 +2204,7 @@ static HRESULT WINAPI d3d_device2_Index(IDirect3DDevice2 *iface, WORD index)
  *
  * Returns:
- *  The return value of IDirect3DDevice7::DrawPrimitive
+ *  The return value of IDirect3DDevice3::DrawPrimitive
  *
  *****************************************************************************/
-- 
1.8.1.5




More information about the wine-patches mailing list